@@ -29,9 +29,6 @@ import z3c.schema.email
 from z3c.authenticator.interfaces import IUser
 from z3c.authenticator.interfaces import IGroup
 
-from p01.remote.interfaces import IRemoteProcessor
-from p01.remote.interfaces import IJob
-
 import p01.fsfile.interfaces
 
 from mypypi.i18n import MessageFactory as _
@@ -128,12 +125,12 @@ class IPYPISite(IRootFolder, IAttributeAnnotatable):
                        '(python setup.py sdist upload)'),
         default=True)
 
-    def syncMirrorPackages():
-        """Update all packages and fetch new releases."""
-
     def getStartTime():
         """Return time the application started in seconds since the epoch."""
 
+    def addMirrorPackage(name, pypiURL):
+        """Add mirror package"""
+
     # PYPI API (used in XML-RPC)
     def getPackages():
         """Returns a list of accessible packages"""
@@ -152,10 +149,6 @@ class IFSStorage(p01.fsfile.interfaces.IBushyFSStorage):
     """Bushy storage with relativ path"""
 
 
-class ISyncMirrorPackages(IJob):
-    """Job which can start the mirror process."""
-
-
 class IPublishable(zope.interface.Interface):
     """Publish API."""
 
